@@ -21,6 +21,7 @@
 #define HAVE_NAN 1
 #define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
 #define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
+#define BROKEN_CRYPT 1
 #define HAVE_CRT_EXTERNS_H 1
 #define HAVE_LIBDL 1
 #define HAVE_DIRENT_H 1
@@ -57,6 +58,7 @@
 #define SIZEOF_LONG 8
 #define SIZEOF_LONG_LONG 8
 #define SIZEOF___INT64 0
+#define SIZEOF___INT128 16
 #define SIZEOF_OFF_T 8
 #define SIZEOF_VOIDP 8
 #define SIZEOF_FLOAT 4
@@ -116,18 +118,23 @@
 #define STRINGIZE(expr) STRINGIZE0(expr)
 #define HAVE_STDARG_PROTOTYPES 1
 #define HAVE_VA_ARGS_MACRO 1
-#define NORETURN(x) __attribute__ ((noreturn)) x
-#define DEPRECATED(x) __attribute__ ((deprecated)) x
-#define DEPRECATED_BY(n,x) __attribute__ ((deprecated("by "#n))) x
-#define DEPRECATED_TYPE(mesg,x) x __attribute__ ((deprecated mesg))
-#define NOINLINE(x) __attribute__ ((noinline)) x
-#define WEAK(x) __attribute__ ((weak)) x
+#define CONSTFUNC(x) __attribute__ ((__const__)) x
+#define PUREFUNC(x) __attribute__ ((__pure__)) x
+#define NORETURN(x) __attribute__ ((__noreturn__)) x
+#define DEPRECATED(x) __attribute__ ((__deprecated__)) x
+#define DEPRECATED_BY(n,x) __attribute__ ((__deprecated__("by "#n))) x
+#define DEPRECATED_TYPE(mesg,x) x __attribute__ ((__deprecated__ mesg))
+#define NOINLINE(x) __attribute__ ((__noinline__)) x
+#define ALWAYS_INLINE(x) __attribute__ ((__always_inline__)) x
+#define WARN_UNUSED_RESULT(x) __attribute__ ((__warn_unused_result__)) x
+#define MAYBE_UNUSED(x) __attribute__ ((__unused__)) x
+#define WEAK(x) __attribute__ ((__weak__)) x
 #define HAVE_FUNC_WEAK 1
-#define FUNC_CDECL(x) __attribute__ ((cdecl)) x
+#define FUNC_CDECL(x) __attribute__ ((__cdecl__)) x
 #define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_SYNC_BUILTINS 1
 #define UNREACHABLE __builtin_unreachable()
-#define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
+#define RUBY_FUNC_EXPORTED __attribute__ ((__visibility__("default"))) extern
 #define RUBY_FUNCTION_NAME_STRING __func__
 #define ENUM_OVER_INT 1
 #define HAVE_DECL_SYS_NERR 1
@@ -170,6 +177,12 @@
 #define SIZEOF_INT64_T 8
 #define HAVE_UINT64_T 1
 #define SIZEOF_UINT64_T 8
+#define HAVE_INT128_T 1
+#define int128_t __int128
+#define SIZEOF_INT128_T SIZEOF___INT128
+#define HAVE_UINT128_T 1
+#define uint128_t unsigned __int128
+#define SIZEOF_UINT128_T SIZEOF___INT128
 #define HAVE_INTPTR_T 1
 #define SIZEOF_INTPTR_T 8
 #define HAVE_UINTPTR_T 1
@@ -206,6 +219,7 @@
 #define vfork fork
 #define HAVE_WORKING_FORK 1
 #define HAVE__LONGJMP 1
+#define HAVE_ARC4RANDOM_BUF 1
 #define HAVE_ATAN2L 1
 #define HAVE_ATAN2F 1
 #define HAVE_CHROOT 1
@@ -298,9 +312,14 @@
 #define HAVE_BUILTIN___BUILTIN_BSWAP16 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP32 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP64 1
+#define HAVE_BUILTIN___BUILTIN_POPCOUNT 1
+#define HAVE_BUILTIN___BUILTIN_POPCOUNTLL 1
 #define HAVE_BUILTIN___BUILTIN_CLZ 1
 #define HAVE_BUILTIN___BUILTIN_CLZL 1
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
+#define HAVE_BUILTIN___BUILTIN_CTZ 1
+#define HAVE_BUILTIN___BUILTIN_CTZLL 1
+#define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
@@ -318,6 +337,7 @@
 #define TIMEZONE_VOID 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
+#define HAVE_SIG_T 1
 #define RSHIFT(x,y) ((x)>>(int)(y))
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
@@ -343,9 +363,11 @@
 #define DLEXT_MAXLEN 7
 #define DLEXT ".bundle"
 #define LIBDIR_BASENAME "lib"
-#define RUBY_SETJMP(env) sigsetjmp((env),0)
-#define RUBY_LONGJMP(env,val) siglongjmp((env),val)
-#define RUBY_JMP_BUF sigjmp_buf
+#define HAVE__SETJMP 1
+#define HAVE_SIGSETJMP 1
+#define RUBY_SETJMP(env) _setjmp((env))
+#define RUBY_LONGJMP(env,val) _longjmp((env),val)
+#define RUBY_JMP_BUF jmp_buf
 #define HAVE_PTHREAD_H 1
 #define RUBY_PLATFORM "x86_64-darwin16"
 #endif /* INCLUDE_RUBY_CONFIG_H */
