@@ -1,29 +1,36 @@
+# encoding: ascii-8bit
 # frozen-string-literal: false
+#
+# The module storing Ruby interpreter configurations on building.
+#
 # This file was created by mkconfig.rb when ruby was built.  It contains
 # build information for ruby which is used e.g. by mkmf to build
 # compatible native extensions.  Any changes made to this file will be
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("2.3.") or
-    raise "ruby lib version (2.3.8) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("2.4.") or
+    raise "ruby lib version (2.4.10) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.3/2.3.0/x86_64-darwin16")
+  # Ruby installed directory.
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.4/2.4.0/x86_64-darwin16")
+  # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
+  # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "3"
-  CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "459"
+  CONFIG["MINOR"] = "4"
+  CONFIG["TEENY"] = "10"
+  CONFIG["PATCHLEVEL"] = "364"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)2.3"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)2.3"
-  CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(MAJOR).$(MINOR).$(TEENY)"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)2.4"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)2.4"
+  CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME).$(RUBY_PROGRAM_VERSION)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.3.pc"
+  CONFIG["ruby_pc"] = "ruby-2.4.pc"
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
   CONFIG["USE_RUBYGEMS"] = "YES"
@@ -38,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-tk' '--without-gmp' '--with-opt-dir=/opt/local' '--with-openssl-include=/opt/local/libexec/openssl10/include' '--with-openssl-lib=/opt/local/libexec/openssl10/lib' '--program-suffix=2.3' '--with-rubylibprefix=/opt/local/lib/ruby2.3' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl10/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl10/include -isystem/opt/local/include' 'CXX=/usr/bin/clang++' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++ -arch x86_64' 'PKG_CONFIG_PATH=/opt/local/libexec/openssl10/lib/pkgconfig'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--enable-install-static-library' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-gmp' '--with-opt-dir=/opt/local' '--program-suffix=2.4' '--with-rubylibprefix=/opt/local/lib/ruby2.4' '--with-openssl-include=/opt/local/libexec/openssl11/include' '--with-openssl-lib=/opt/local/libexec/openssl11/lib' 'LIBPATHENV=DYLD_FALLBACK_LIBRARY_PATH' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'CXX=/usr/bin/clang++' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++ -arch x86_64'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -48,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.3.0"
+  CONFIG["ruby_version"] = "2.4.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-darwin16"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -87,11 +94,12 @@ module RbConfig
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = ""
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wshorten-64-to-32 -Wimplicit-function-declaration -Wdivision-by-zero -Wdeprecated-declarations -Wextra-tokens"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wno-tautological-compare -Wno-parentheses-equality -Wno-constant-logical-operand -Wno-self-assign -Wunused-variable -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wshorten-64-to-32 -Wimplicit-function-declaration -Wdivision-by-zero -Wdeprecated-declarations -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["NULLCMD"] = ":"
   CONFIG["DLNOBJ"] = "dln.o"
+  CONFIG["INSTALL_STATIC_LIBRARY"] = "yes"
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
   CONFIG["LIBRUBY_RELATIVE"] = "no"
@@ -99,14 +107,14 @@ module RbConfig
   CONFIG["PREP"] = "miniruby$(EXEEXT) ruby-runner$(EXEEXT)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
-  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.3"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.4"
   CONFIG["setup"] = "Setup"
   CONFIG["ENCSTATIC"] = ""
   CONFIG["EXTSTATIC"] = ""
   CONFIG["STRIP"] = "strip -A -n"
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "DYLD_INSERT_LIBRARIES"
-  CONFIG["LIBPATHENV"] = "DYLD_LIBRARY_PATH"
+  CONFIG["LIBPATHENV"] = "DYLD_FALLBACK_LIBRARY_PATH"
   CONFIG["RPATHFLAG"] = ""
   CONFIG["LIBPATHFLAG"] = " -L%s"
   CONFIG["LINK_SO"] = "\n$(POSTLINK)"
@@ -119,7 +127,7 @@ module RbConfig
   CONFIG["CCDLFLAGS"] = "-fno-common"
   CONFIG["STATIC"] = ""
   CONFIG["ARCH_FLAG"] = " -arch x86_64"
-  CONFIG["DLDFLAGS"] = "-Wl,-undefined,dynamic_lookup -Wl,-multiply_defined,suppress -L/opt/local/lib"
+  CONFIG["DLDFLAGS"] = "-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names  -arch x86_64 -Wl,-undefined,dynamic_lookup -Wl,-multiply_defined,suppress -L/opt/local/lib"
   CONFIG["ALLOCA"] = ""
   CONFIG["codesign"] = "codesign"
   CONFIG["POSTLINK"] = "test -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@"
@@ -131,7 +139,6 @@ module RbConfig
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
   CONFIG["PKG_CONFIG"] = "pkg-config"
-  CONFIG["PKG_CONFIG_PATH"] = "/opt/local/libexec/openssl10/lib/pkgconfig"
   CONFIG["PYTHON"] = ""
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
@@ -153,7 +160,9 @@ module RbConfig
   CONFIG["AR"] = "libtool -static"
   CONFIG["RANLIB"] = ":"
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION"] = "$(CC) -v"
+  CONFIG["CC_VERSION_MESSAGE"] = "Apple LLVM version 9.0.0 (clang-900.0.39.2)\nTarget: x86_64-apple-darwin16.7.0\nThread model: posix\nInstalledDir: /Library/Developer/CommandLineTools/usr/bin"
+  CONFIG["CC_VERSION"] = "$(CC) --version"
+  CONFIG["CSRCFLAG"] = ""
   CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
@@ -163,11 +172,11 @@ module RbConfig
   CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++"
+  CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -stdlib=libc++"
   CONFIG["OBJEXT"] = "o"
-  CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl10/include -isystem/opt/local/include -I/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl10/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -fstack-protector -L/opt/local/lib"
-  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl10/include -Os -fno-common"
+  CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl11/include -isystem/opt/local/include -I/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
+  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -fstack-protector -L/opt/local/lib"
+  CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl11/include -Os -fno-common"
   CONFIG["CXX"] = "/usr/bin/clang++"
   CONFIG["CC"] = "/usr/bin/clang"
   CONFIG["NACL_LIB_PATH"] = ""
@@ -189,10 +198,10 @@ module RbConfig
   CONFIG["build_vendor"] = "apple"
   CONFIG["build_cpu"] = "x86_64"
   CONFIG["build"] = "x86_64-apple-darwin16.7.0"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.3.8"
-  CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.10"
+  CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = ""
-  CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
+  CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
@@ -212,6 +221,7 @@ module RbConfig
   CONFIG["docdir"] = "$(datarootdir)/doc/$(PACKAGE)"
   CONFIG["oldincludedir"] = "$(SDKROOT)""/usr/include"
   CONFIG["includedir"] = "$(prefix)/include"
+  CONFIG["runstatedir"] = "$(localstatedir)/run"
   CONFIG["localstatedir"] = "$(prefix)/var"
   CONFIG["sharedstatedir"] = "$(prefix)/com"
   CONFIG["sysconfdir"] = "$(prefix)/etc"
@@ -220,7 +230,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&2.3&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&2.4&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
@@ -230,11 +240,45 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
+  CONFIG["UNICODE_VERSION"] = "9.0.0"
   CONFIG["SDKROOT"] = ENV["SDKROOT"] || "" # don't run xcrun everytime, usually useless.
   CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
+  # Almost same with CONFIG. MAKEFILE_CONFIG has other variable
+  # reference like below.
+  #
+  #   MAKEFILE_CONFIG["bindir"] = "$(exec_prefix)/bin"
+  #
+  # The values of this constant is used for creating Makefile.
+  #
+  #   require 'rbconfig'
+  #
+  #   print <<-END_OF_MAKEFILE
+  #   prefix = #{Config::MAKEFILE_CONFIG['prefix']}
+  #   exec_prefix = #{Config::MAKEFILE_CONFIG['exec_prefix']}
+  #   bindir = #{Config::MAKEFILE_CONFIG['bindir']}
+  #   END_OF_MAKEFILE
+  #
+  #   => prefix = /usr/local
+  #      exec_prefix = $(prefix)
+  #      bindir = $(exec_prefix)/bin  MAKEFILE_CONFIG = {}
+  #
+  # RbConfig.expand is used for resolving references like above in rbconfig.
+  #
+  #   require 'rbconfig'
+  #   p Config.expand(Config::MAKEFILE_CONFIG["bindir"])
+  #   # => "/usr/local/bin"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
+
+  # call-seq:
+  #
+  #   RbConfig.expand(val)         -> string
+  #   RbConfig.expand(val, config) -> string
+  #
+  # expands variable with given +val+ value.
+  #
+  #   RbConfig.expand("$(bindir)") # => /home/foobar/all-ruby/ruby19x/bin
   def RbConfig::expand(val, config = CONFIG)
     newval = val.gsub(/\$\$|\$\(([^()]+)\)|\$\{([^{}]+)\}/) {
       var = $&
@@ -257,6 +301,10 @@ module RbConfig
     RbConfig::expand(val)
   end
 
+  # call-seq:
+  #
+  #   RbConfig.ruby -> path
+  #
   # returns the absolute pathname of the ruby command.
   def RbConfig.ruby
     File.join(
